==> ssp_api-1.3.2.1-sources.jar: com/cloud/hisavana/sdk/ad/base/PlatformUtil.java <==
package com.cloud.hisavana.sdk.ad.base;
/* Top Secret */

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.ResolveInfo;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;

import com.cloud.hisavana.sdk.common.athena.AthenaTracker;
import com.cloud.hisavana.sdk.common.constant.Constants;
import com.cloud.hisavana.sdk.common.tracking.TrackingBean;
import com.cloud.hisavana.sdk.common.tracking.TrackingUtil;
import com.cloud.hisavana.sdk.config.AdxServerConfig;
import com.cloud.hisavana.sdk.data.bean.response.AdsDTO;
import com.cloud.hisavana.sdk.common.activity.TAdExposureActivity;
import com.cloud.hisavana.sdk.common.bean.AdImage;
import com.cloud.hisavana.sdk.common.bean.TaNativeInfo;
import com.cloud.hisavana.sdk.common.tracking.DownUpPointBean;
import com.cloud.hisavana.sdk.common.tracking.TrackingManager;
import com.cloud.hisavana.sdk.common.util.AdLogUtil;
import com.cloud.hisavana.sdk.common.util.SensitiveUtil;

import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;


/**
 * 广告封装工具类
 *
 * @author $韦明微
 * @data 2016/11/25
 * ========================================
 * CopyRight (c) 2016 TRANSSION.Co.Ltd.
 * All rights reserved.
 */

public class PlatformUtil {

    private static TaNativeInfo extTAd(AdsDTO adItem) {

        TaNativeInfo nativeInfo = new TaNativeInfo();

        // 埋点用的
        nativeInfo.adItem = adItem;

        if (adItem == null || adItem.getNativeObject() == null) {
            nativeInfo = null;
            return nativeInfo;
        }

        try {
            String uuid = UUID.randomUUID().toString().replaceAll("-", "");
            adItem.setUuid(uuid);
            nativeInfo.uuid = uuid;
            nativeInfo.setSequenceId(String.valueOf(adItem.getId()));
            nativeInfo.setVer(adItem.getNativeObject().getVersion());
            nativeInfo.setCtatext(adItem.getNativeObject().getButtonTxt(adItem.getInstallApk()));
            nativeInfo.setDescription(adItem.getNativeObject().getDescriptionTxt());
            nativeInfo.setTitle(adItem.getNativeObject().getTitleTxt());
            //没用到
            nativeInfo.setPrice(String.valueOf(adItem.getFirstPrice()));
            nativeInfo.setBidPrice(adItem.getFirstPrice());
            nativeInfo.setRating(String.valueOf(adItem.getNativeObject().getRating()));
            nativeInfo.setRequestId(adItem.getRid());

            AdImage image = new AdImage();
            if (adItem.getNativeObject().getMainImages() != null
                    && adItem.getNativeObject().getMainImages().size() > 0
                    && adItem.getNativeObject().getMainImages().get(0) != null) {
                image.setH(adItem.getNativeObject().getMainImages().get(0).getHeight());
                image.setW(adItem.getNativeObject().getMainImages().get(0).getWidth());
                image.setImgUrl(adItem.getNativeObject().getMainImages().get(0).getUrl());
            } else {
                image.setH(0);
                image.setW(0);
                image.setImgUrl("");
            }
            nativeInfo.setImage(image);

            //icon
            AdImage icon = new AdImage();
            icon.setH(adItem.getNativeObject().getLogo() == null ? 0 : adItem.getNativeObject().getLogo().getHeight());
            icon.setW(adItem.getNativeObject().getLogo() == null ? 0 : adItem.getNativeObject().getLogo().getWidth());
            icon.setImgUrl(adItem.getNativeObject().getLogo() == null ? "" : adItem.getNativeObject().getLogo().getUrl());
            nativeInfo.setIconImage(icon);

            //adchoice
            nativeInfo.acImageUrl = adItem.getAdChoiceImageUrl() == null ? "" : adItem.getAdChoiceImageUrl();
            nativeInfo.acClickUrl = adItem.getAdChoiceClickUrl() == null ? "" : adItem.getAdChoiceClickUrl();
            //1.5版本  native改成模板渲染
            nativeInfo.advSeatType = adItem.getAdvSeatType();
            nativeInfo.materialStyle = adItem.getMaterialStyle();
        } catch (Throwable e) {
            AdLogUtil.Log().e(Log.getStackTraceString(e));
            nativeInfo = null;
        }
        return nativeInfo;
    }

    /**
     * 查找对应的adBean
     *
     * @param nativeInfo
     * @return AdBean
     */
    public static AdsDTO getAdBean(TaNativeInfo nativeInfo, List<AdsDTO> adBeans) {
        if (nativeInfo != null) {
            if (adBeans != null && !adBeans.isEmpty()) {
                for (AdsDTO item : adBeans) {
                    if (item != null && nativeInfo.uuid.equals(item.getUuid())) {
                        item.setACReady(nativeInfo.isACReady);
                        //native更改二价
                        item.setSecondPrice(nativeInfo.getSecondPrice());
                        return item;
                    }
                }
            }
        }
        return null;
    }

    /**
     * 获取多个Native的信息
     */
    public static List<TaNativeInfo> getTadNativeInfoList(List<AdsDTO> items) {
        List<TaNativeInfo> infoList = new ArrayList<>();
        for (AdsDTO adItem : items) {
            if (adItem == null) {
                continue;
            }
            TaNativeInfo nativeInfo = extTAd(adItem);
            if (nativeInfo == null) {
                continue;
            }
            if (SensitiveUtil.isSensitive(nativeInfo)) {
                continue;
            }
            infoList.add(nativeInfo);
        }
        return infoList;
    }

    /**
     * 所有的点击事件都走这一个方法
     *  if(下载类应用){
     *       if(deelink不是空){
     *            打开deeplink；；
     *        }else {
     *           打开目标应用；
     *        }
     *   }
     *   打开landingpage；
     */
    public static boolean startActivity(Context context, AdsDTO adItem, DownUpPointBean pointBean) {

        if (context == null) {
            AdLogUtil.Log().d(AdLogUtil.TAG,"context is null");
            return false;
        }
        final boolean newTask = (context == context.getApplicationContext() ? true : false);

        if (adItem == null) {
            AdLogUtil.Log().d(AdLogUtil.TAG,"adItem is null");
            return false;
        }

        // 第三方归因服务 两个事件 用一个 clickid
        String clickid = TrackingUtil.getTriggerId();

        String landingUrl = adItem.getClickUrl();
        AdLogUtil.Log().d(AdLogUtil.TAG,"landing url is : " + landingUrl);
        TrackingBean trackingBean = new TrackingBean(landingUrl,clickid,adItem.getNewPrice_Click(),adItem.getInstallApk());

        // 第三方归因服务 只要点击了 就发送请求  adItem 判空 外面已经判断了
        TrackingManager.clickTrackingUrlsExposure(adItem.getClickTrackingUrls(), clickid);

        //StoreDeeplink不为空
        if (adItem.getStoreDeeplink()!= null && adItem.getStoreDeeplink().size() > 0) {
            Intent intent = new Intent();
            for (String linkUrl : adItem.getStoreDeeplink()){
                if (TextUtils.isEmpty(linkUrl))continue;
                try {
                    //打开短信编辑页面，带内容，例子：smsto:10086:%E7%A7%8D%E6%96%B9%E6%B3%95
                    if (linkUrl.startsWith(Constants.SMSTO) && linkUrl.split(":").length > 2){
                        //first-smsto:  number-10086  sms_body-发送内容
                        String first = linkUrl.substring(0,linkUrl.indexOf(":") + 1);
                        String first_remain = linkUrl.substring(linkUrl.indexOf(":") + 1);
                        int index = first_remain.indexOf(":");
                        String number = first_remain.substring(0,index);
                        String sms_body = URLDecoder.decode(first_remain.substring(index + 1),"UTF-8");
                        linkUrl = first + number;
                        intent.putExtra(Constants.SMS_BODY, sms_body);
                        AdLogUtil.Log().d(AdLogUtil.TAG,"linkUrl:" + linkUrl + ",sms_body:" + sms_body);
                    }
                }catch (Exception e){
                    AdLogUtil.Log().d(AdLogUtil.TAG,"deeplink SMSTO process error");
                }

                Uri content_uri = Uri.parse(linkUrl);
                intent.setData(content_uri);
                intent.setAction("android.intent.action.VIEW");
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                boolean flag = true;
                try {
                    context.startActivity(intent);
                    //设置首次
                    adItem.setDeepLinkUrlFirst(linkUrl);
                } catch (Throwable e) {
                    AdLogUtil.Log().e("deepLinkUrl error - " + Log.getStackTraceString(e));
                    flag = false;
                }
                if (flag) {
                    //上报deeplink事件
                    AthenaTracker.trackDeeplink(adItem);
                    //服务端点击上报
                    TrackingManager.reportServerClick(pointBean,trackingBean);
                    return true;
                }
            }
        }else {
            if (!TextUtils.isEmpty(adItem.getPackageName())){
                //deeplink为空，打开目标应用
                if (startApplicationWithPackageName(context,adItem.getPackageName(),newTask))return true;
            }
        }
        //打开landingUrl
        if (!TextUtils.isEmpty(landingUrl) && (landingUrl.startsWith("http") || landingUrl.startsWith("https://"))) {
            if (AdxServerConfig.isForAutoTest()) {
                startPageByBrowser(context, landingUrl);
            } else {
                startPageByWebView(context,newTask, true, pointBean, trackingBean);
            }
            return true;
        } else {
            AdLogUtil.Log().d(AdLogUtil.TAG,"Both deepLinkUrl and landing page is null");
            return false;
        }

    }

    /**
     * 通过包名或类名启动另一个APP
     * @param context
     * @param packagename
     */
    private static boolean startApplicationWithPackageName(Context context,String packagename,boolean newTask) {
        try {
            // 通过包名获取此APP详细信息，包括Activities、services、versioncode、name等等
            PackageInfo packageinfo = context.getPackageManager().getPackageInfo(packagename, 0);
            if (packageinfo == null) {
                return false;
            }

            // 创建一个类别为CATEGORY_LAUNCHER的该包名的Intent
            Intent resolveIntent = new Intent(Intent.ACTION_MAIN, null);
            resolveIntent.addCategory(Intent.CATEGORY_LAUNCHER);
            resolveIntent.setPackage(packageinfo.packageName);

            // 通过getPackageManager()的queryIntentActivities方法遍历
            List<ResolveInfo> resolveinfoList = context.getPackageManager()
                    .queryIntentActivities(resolveIntent, 0);
            if (resolveinfoList == null || resolveinfoList.size() == 0){
                return false;
            }
            ResolveInfo resolveinfo = resolveinfoList.iterator().next();
            if (resolveinfo != null) {
                // packagename = 参数packname
                String packageName = resolveinfo.activityInfo.packageName;
                // 这个就是我们要找的该APP的LAUNCHER的Activity[组织形式：packagename.mainActivityname]
                String className = resolveinfo.activityInfo.name;
                // LAUNCHER Intent
                Intent intent = new Intent(Intent.ACTION_MAIN);
                intent.addCategory(Intent.CATEGORY_LAUNCHER);
                if (newTask) {
                    intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                }
                // 设置ComponentName参数1:packagename参数2:MainActivity路径
                ComponentName cn = new ComponentName(packageName, className);

                intent.setComponent(cn);
                context.startActivity(intent);
                return true;
            }
            return false;
        }catch (Exception e){
            AdLogUtil.Log().e(AdLogUtil.TAG,  "PlatformUtil" + Log.getStackTraceString(e));
            return false;
        }
    }
    /**
     * 用于adchoices
     */
    public static void startPageByWebView(Context context, String url) {
        startPageByWebView(context, true, false, null, new TrackingBean(url,"","",-1));
    }
    /**
     * 广告的点击 和 adChoices都用的同一个
     *
     * @param context
     * @param newTask
     * @param isAdClick
     * @param trackingBean
     */
    public static void startPageByWebView(Context context, boolean newTask, boolean isAdClick, DownUpPointBean pointBean, TrackingBean trackingBean) {
        AdLogUtil.Log().d(AdLogUtil.TAG,"Start page with WebView.");
        Intent intent = new Intent(context, TAdExposureActivity.class);
        Bundle bundle = new Bundle();
        bundle.putSerializable("trackingBean", trackingBean);
        if (isAdClick) {
            bundle.putSerializable("pointBean", pointBean);
            bundle.putBoolean("isAdClick", true);
        }
        intent.putExtras(bundle);
        if (newTask) {
            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        }
        context.startActivity(intent);
    }


    /**
     * 用浏览器 打开webView
     *
     * @param context
     * @param url
     */
    public static void startPageByBrowser(Context context, String url) {
        boolean isOk = startPageWithChrome(context, url, true);
        if (!isOk) {
            AdLogUtil.Log().d(AdLogUtil.TAG,"Start page with Chrome Browser failed,Start default Browser.");
            startDefaultBrowser(context, url, true);
        }
    }

    private static boolean startDefaultBrowser(Context context, String landingUrl, boolean newTask) {
        try {
            Intent intent = new Intent();
            intent.setAction("android.intent.action.VIEW");
            Uri content_uri = Uri.parse(landingUrl);
            intent.setData(content_uri);
            if (newTask) {
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
            }
            context.startActivity(intent);
            return true;
        } catch (Throwable e) {
            AdLogUtil.Log().e(Log.getStackTraceString(e));
            return false;
        }

    }

    /**
     * 开启activity
     *
     * @param context
     * @param landingUrl
     */
    private final static String DEFAULT_BROWSER_PACKAGE = "com.android.chrome";

    private static boolean startPageWithChrome(Context context, String url, boolean newTask) {
        boolean isOk = true;
        try {
            Intent intent = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
            intent.setPackage(DEFAULT_BROWSER_PACKAGE);
            if (newTask) {
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
            }
            context.startActivity(intent);
        } catch (Throwable e1) {
            isOk = false;
        }
        return isOk;
    }

}

==> ssp_api-1.3.3.3-sources.jar: com/cloud/hisavana/sdk/ad/base/PlatformUtil.java <==
package com.cloud.hisavana.sdk.ad.base;
/* Top Secret */

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.ResolveInfo;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;

import com.cloud.hisavana.sdk.common.athena.AthenaTracker;
import com.cloud.hisavana.sdk.common.constant.Constants;
import com.cloud.hisavana.sdk.common.tracking.TrackingBean;
import com.cloud.hisavana.sdk.common.tracking.TrackingUtil;
import com.cloud.hisavana.sdk.config.AdxServerConfig;
import com.cloud.hisavana.sdk.data.bean.response.AdsDTO;
import com.cloud.hisavana.sdk.common.activity.TAdExposureActivity;
import com.cloud.hisavana.sdk.common.bean.AdImage;
import com.cloud.hisavana.sdk.common.bean.TaNativeInfo;
import com.cloud.hisavana.sdk.common.tracking.DownUpPointBean;
import com.cloud.hisavana.sdk.common.tracking.TrackingManager;
import com.cloud.hisavana.sdk.common.util.AdLogUtil;
import com.cloud.hisavana.sdk.common.util.SensitiveUtil;
import com.cloud.hisavana.sdk.offline.OffLineManager;
import java.io.File;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;


/**
 * 广告封装工具类
 *
 * @author $韦明微
 * @data 2016/11/25
 * ========================================
 * CopyRight (c) 2016 TRANSSION.Co.Ltd.
 * All rights reserved.
 */

public class PlatformUtil {

    private static TaNativeInfo extTAd(AdsDTO adItem) {

        TaNativeInfo nativeInfo = new TaNativeInfo();

        // 埋点用的
        nativeInfo.adItem = adItem;

        if (adItem == null || adItem.getNativeObject() == null) {
            nativeInfo = null;
            return nativeInfo;
        }

        try {
            String uuid = UUID.randomUUID().toString().replaceAll("-", "");
            adItem.setUuid(uuid);
            nativeInfo.uuid = uuid;
            nativeInfo.setSequenceId(String.valueOf(adItem.getId()));
            nativeInfo.setVer(adItem.getNativeObject().getVersion());
            nativeInfo.setCtatext(adItem.getNativeObject().getButtonTxt(adItem.getInstallApk()));
            nativeInfo.setDescription(adItem.getNativeObject().getDescriptionTxt());
            nativeInfo.setTitle(adItem.getNativeObject().getTitleTxt());
            //没用到
            nativeInfo.setPrice(String.valueOf(adItem.getFirstPrice()));
            nativeInfo.setBidPrice(adItem.getFirstPrice());
            nativeInfo.setRating(String.valueOf(adItem.getNativeObject().getRating()));
            nativeInfo.setRequestId(adItem.getRid());

            AdImage image = new AdImage();
            if (adItem.getNativeObject().getMainImages() != null
                    && adItem.getNativeObject().getMainImages().size() > 0
                    && adItem.getNativeObject().getMainImages().get(0) != null) {
                image.setH(adItem.getNativeObject().getMainImages().get(0).getHeight());
                image.setW(adItem.getNativeObject().getMainImages().get(0).getWidth());
                image.setImgUrl(adItem.getNativeObject().getMainImages().get(0).getUrl());
            } else {
                image.setH(0);
                image.setW(0);
                image.setImgUrl("");
            }
            nativeInfo.setImage(image);

            //icon
            AdImage icon = new AdImage();
            icon.setH(adItem.getNativeObject().getLogo() == null ? 0 : adItem.getNativeObject().getLogo().getHeight());
            icon.setW(adItem.getNativeObject().getLogo() == null ? 0 : adItem.getNativeObject().getLogo().getWidth());
            icon.setImgUrl(adItem.getNativeObject().getLogo() == null ? "" : adItem.getNativeObject().getLogo().getUrl());
            nativeInfo.setIconImage(icon);

            //adchoice
            nativeInfo.acImageUrl = adItem.getAdChoiceImageUrl() == null ? "" : adItem.getAdChoiceImageUrl();
            nativeInfo.acClickUrl = adItem.getAdChoiceClickUrl() == null ? "" : adItem.getAdChoiceClickUrl();
            //1.5版本  native改成模板渲染
            nativeInfo.advSeatType = adItem.getAdvSeatType();
            nativeInfo.materialStyle = adItem.getMaterialStyle();
        } catch (Throwable e) {
            AdLogUtil.Log().e(Log.getStackTraceString(e));
            nativeInfo = null;
        }
        return nativeInfo;
    }

    /**
     * 查找对应的adBean
     *
     * @param nativeInfo
     * @return AdBean
     */
    public static AdsDTO getAdBean(TaNativeInfo nativeInfo, List<AdsDTO> adBeans) {
        if (nativeInfo != null) {
            if (adBeans != null && !adBeans.isEmpty()) {
                for (AdsDTO item : adBeans) {
                    if(nativeInfo.adItem ==null ){
                        continue;
                    }
                    if (item != null && nativeInfo.adItem.getUuid().equals(item.getUuid())) {
                        item.setACReady(nativeInfo.isACReady);
                        //native更改二价
                        item.setSecondPrice(nativeInfo.getSecondPrice());
                        return item;
                    }
                }
            }
        }
        return null;
    }

    /**
     * 获取多个Native的信息
     */
    public static List<TaNativeInfo> getTadNativeInfoList(List<AdsDTO> items) {
        List<TaNativeInfo> infoList = new ArrayList<>();
        for (AdsDTO adItem : items) {
            if (adItem == null) {
                continue;
            }
            TaNativeInfo nativeInfo = extTAd(adItem);
            if (nativeInfo == null) {
                continue;
            }
            if (SensitiveUtil.isSensitive(nativeInfo)) {
                continue;
            }
            infoList.add(nativeInfo);
        }
        return infoList;
    }

    /**
     * 所有的点击事件都走这一个方法
     * if(下载类应用){
     * if(deelink不是空){
     * 打开deeplink；；
     * }else {
     * 打开目标应用；
     * }
     * }
     * 打开landingpage；
     */
    public static boolean startActivity(Context context, AdsDTO adItem, DownUpPointBean pointBean) {

        if (context == null) {
            AdLogUtil.Log().d(AdLogUtil.TAG, "context is null");
            return false;
        }
        final boolean newTask = (context == context.getApplicationContext() ? true : false);

        if (adItem == null) {
            AdLogUtil.Log().d(AdLogUtil.TAG, "adItem is null");
            return false;
        }

        // 第三方归因服务 两个事件 用一个 clickid
        String clickid = TrackingUtil.getTriggerId();

        String landingUrl = adItem.getClickUrl();
        AdLogUtil.Log().d(AdLogUtil.TAG,"landing url is : " + landingUrl);
        TrackingBean trackingBean = new TrackingBean(landingUrl,clickid,adItem.getNewPrice_Click(),adItem.getInstallApk(),adItem);

        // 第三方归因服务 只要点击了 就发送请求  adItem 判空 外面已经判断了
        TrackingManager.clickTrackingUrlsExposure(adItem.getClickTrackingUrls(), clickid);

        //StoreDeeplink不为空
        if (adItem.getStoreDeeplink() != null && adItem.getStoreDeeplink().size() > 0) {
            Intent intent = new Intent();
            for (String linkUrl : adItem.getStoreDeeplink()) {
                if (TextUtils.isEmpty(linkUrl)) continue;
                try {
                    //打开短信编辑页面，带内容，例子：smsto:10086:%E7%A7%8D%E6%96%B9%E6%B3%95
                    if (linkUrl.startsWith(Constants.SMSTO) && linkUrl.split(":").length > 2) {
                        //first-smsto:  number-10086  sms_body-发送内容
                        String first = linkUrl.substring(0, linkUrl.indexOf(":") + 1);
                        String first_remain = linkUrl.substring(linkUrl.indexOf(":") + 1);
                        int index = first_remain.indexOf(":");
                        String number = first_remain.substring(0, index);
                        String sms_body = URLDecoder.decode(first_remain.substring(index + 1), "UTF-8");
                        linkUrl = first + number;
                        intent.putExtra(Constants.SMS_BODY, sms_body);
                        AdLogUtil.Log().d(AdLogUtil.TAG, "linkUrl:" + linkUrl + ",sms_body:" + sms_body);
                    }
                } catch (Exception e) {
                    AdLogUtil.Log().d(AdLogUtil.TAG, "deeplink SMSTO process error");
                }

                Uri content_uri = Uri.parse(linkUrl);
                intent.setData(content_uri);
                intent.setAction("android.intent.action.VIEW");
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                boolean flag = true;
                try {
                    context.startActivity(intent);
                    //设置首次
                    adItem.setDeepLinkUrlFirst(linkUrl);
                } catch (Throwable e) {
                    AdLogUtil.Log().e("deepLinkUrl error - " + Log.getStackTraceString(e));
                    flag = false;
                }
                if (flag) {
                    //上报deeplink事件
                    AthenaTracker.trackDeeplink(adItem);
                    //服务端点击上报
                    TrackingManager.reportServerClick(pointBean,trackingBean);
                    return true;
                }
            }
        } else {
            if (!TextUtils.isEmpty(adItem.getPackageName())) {
                //deeplink为空，打开目标应用
                if (startApplicationWithPackageName(context, adItem.getPackageName(), newTask))
                    return true;
            }
        }
        if (adItem.isOffLineAd()) {
           String h5FilePath = OffLineManager.getInstance().getCacheFilePath(adItem.getClickUrl());
            if(!TextUtils.isEmpty(h5FilePath)){
                startPageByWebView(context, newTask, true, pointBean,trackingBean);
                return true;
            }else{
                AdLogUtil.Log().d(AdLogUtil.OFF_LINE_TAG, "落地页文件不存在");
                return false;
            }
        }
        //打开landingUrl
        if (!TextUtils.isEmpty(landingUrl) && (landingUrl.startsWith("http") || landingUrl.startsWith("https://"))) {
            if (AdxServerConfig.isForAutoTest()) {
                startPageByBrowser(context, landingUrl);
            } else {
                startPageByWebView(context,newTask, true, pointBean, trackingBean);
            }
            return true;
        } else {
            AdLogUtil.Log().d(AdLogUtil.TAG, "Both deepLinkUrl and landing page is null");
            return false;
        }

    }

    /**
     * 通过包名或类名启动另一个APP
     *
     * @param context
     * @param packagename
     */
    private static boolean startApplicationWithPackageName(Context context, String packagename, boolean newTask) {
        try {
            // 通过包名获取此APP详细信息，包括Activities、services、versioncode、name等等
            PackageInfo packageinfo = context.getPackageManager().getPackageInfo(packagename, 0);
            if (packageinfo == null) {
                return false;
            }

            // 创建一个类别为CATEGORY_LAUNCHER的该包名的Intent
            Intent resolveIntent = new Intent(Intent.ACTION_MAIN, null);
            resolveIntent.addCategory(Intent.CATEGORY_LAUNCHER);
            resolveIntent.setPackage(packageinfo.packageName);

            // 通过getPackageManager()的queryIntentActivities方法遍历
            List<ResolveInfo> resolveinfoList = context.getPackageManager()
                    .queryIntentActivities(resolveIntent, 0);
            if (resolveinfoList == null || resolveinfoList.size() == 0) {
                return false;
            }
            ResolveInfo resolveinfo = resolveinfoList.iterator().next();
            if (resolveinfo != null) {
                // packagename = 参数packname
                String packageName = resolveinfo.activityInfo.packageName;
                // 这个就是我们要找的该APP的LAUNCHER的Activity[组织形式：packagename.mainActivityname]
                String className = resolveinfo.activityInfo.name;
                // LAUNCHER Intent
                Intent intent = new Intent(Intent.ACTION_MAIN);
                intent.addCategory(Intent.CATEGORY_LAUNCHER);
                if (newTask) {
                    intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                }
                // 设置ComponentName参数1:packagename参数2:MainActivity路径
                ComponentName cn = new ComponentName(packageName, className);

                intent.setComponent(cn);
                context.startActivity(intent);
                return true;
            }
            return false;
        } catch (Exception e) {
            AdLogUtil.Log().e(AdLogUtil.TAG, "PlatformUtil" + Log.getStackTraceString(e));
            return false;
        }
    }

    /**
     * 用于adchoices
     */
    public static void startPageByWebView(Context context, String url) {
        startPageByWebView(context, true, false, null, new TrackingBean(url,"","",-1));
    }

    /**
     * 广告的点击 和 adChoices都用的同一个
     *
     * @param context
     * @param newTask
     * @param isAdClick
     * @param trackingBean
     */
    public static void startPageByWebView(Context context, boolean newTask, boolean isAdClick, DownUpPointBean pointBean, TrackingBean trackingBean) {
        AdLogUtil.Log().d(AdLogUtil.TAG,"Start page with WebView.");
        Intent intent = new Intent(context, TAdExposureActivity.class);
        Bundle bundle = new Bundle();
        bundle.putSerializable("trackingBean", trackingBean);
        if (isAdClick) {
            bundle.putSerializable("pointBean", pointBean);
            bundle.putBoolean("isAdClick", true);
        }
        intent.putExtras(bundle);
        if (newTask) {
            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        }
        context.startActivity(intent);
    }


    /**
     * 用浏览器 打开webView
     *
     * @param context
     * @param url
     */
    public static void startPageByBrowser(Context context, String url) {
        boolean isOk = startPageWithChrome(context, url, true);
        if (!isOk) {
            AdLogUtil.Log().d(AdLogUtil.TAG, "Start page with Chrome Browser failed,Start default Browser.");
            startDefaultBrowser(context, url, true);
        }
    }

    private static boolean startDefaultBrowser(Context context, String landingUrl, boolean newTask) {
        try {
            Intent intent = new Intent();
            intent.setAction("android.intent.action.VIEW");
            Uri content_uri = Uri.parse(landingUrl);
            intent.setData(content_uri);
            if (newTask) {
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
            }
            context.startActivity(intent);
            return true;
        } catch (Throwable e) {
            AdLogUtil.Log().e(Log.getStackTraceString(e));
            return false;
        }

    }

    /**
     * 开启activity
     *
     * @param context
     * @param landingUrl
     */
    private final static String DEFAULT_BROWSER_PACKAGE = "com.android.chrome";

    private static boolean startPageWithChrome(Context context, String url, boolean newTask) {
        boolean isOk = true;
        try {
            Intent intent = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
            intent.setPackage(DEFAULT_BROWSER_PACKAGE);
            if (newTask) {
                intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
            }
            context.startActivity(intent);
        } catch (Throwable e1) {
            isOk = false;
        }
        return isOk;
    }

}
